package Common is

   pragma Pure;
   type Pool_Type is abstract tagged limited private;
   --  the root of a remote derivation type must be
   --+ defined in a Pure package (i.e. one with no state)

   type Partition_ID is new Natural;
   Partitions : constant := 3;
   --  the "Partitions" value must be as the value
   --+ set in the configuration file (erat_quater.cfg)

   --  the upper end of the number range searched for primes
   Limit    : constant Positive := 500;

   --  the size of the array in which each partition stores its primes
   Capacity : constant Positive := Limit / Partitions;

   --  the abstract specification of the procedure
   --+ which must be implemented by all partitions
   --+ (which we achieve by simply copying the implementing unit
   --+ in each partition, cf. configuration file)
   --+
   --+ the RPC to the corresponding procedure body
   --+ will be dynamically bound to one specific implementation
   --+ instance in one specific partition
   procedure Test_Primarity
     (Pool    : access Pool_Type;
      Number  : in     Natural) is abstract;

private

   type Pool_Type is abstract tagged limited null record;

end Common;
